==> piwigo-2.3.4.zip: piwigo/language/uk_UA/install.lang.php <==
<?php
// +-----------------------------------------------------------------------+
// | Piwigo - a PHP based photo gallery                                    |
// +-----------------------------------------------------------------------+
// | Copyright(C) 2008-2012 Piwigo Team                  http://piwigo.org |
// | Copyright(C) 2003-2008 PhpWebGallery Team    http://phpwebgallery.net |
// | Copyright(C) 2002-2003 Pierrick LE GALL   http://le-gall.net/pierrick |
// +-----------------------------------------------------------------------+
// | This program is free software; you can redistribute it and/or modify  |
// | it under the terms of the GNU General Public License as published by  |
// | the Free Software Foundation                                          |
// |                                                                       |
// | This program is distributed in the hope that it will be useful, but   |
// | WITHOUT ANY WARRANTY; without even the implied warranty of            |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU      |
// | General Public License for more details.                              |
// |                                                                       |
// | You should have received a copy of the GNU General Public License     |
// | along with this program; if not, write to the Free Software           |
// | Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, |
// | USA.                                                                  |
// +-----------------------------------------------------------------------+
$lang['Admin configuration'] = 'Конфігурація адміністратора';
$lang['also given by your host provider'] = 'також дізнайтесь у Вашого хостинг-провайдера';
$lang['An alternate solution is to copy the text in the box above and paste it into the file "local/config/database.inc.php" (Warning : database.inc.php must only contain what is in the textarea, no line return or space character)'] = 'Альтернативним рішенням є копіювання тексту в поле вище і вставте його в файл "local/config/database.inc.php" (Попередження: database.inc.php повинен містити тільки те, що в текстовому полі, без зворотної лінії або пропусків)';
$lang['Basic configuration'] = 'Базова конфігурація';
$lang['Can\'t connect to server'] = 'Не вдається підключитися до сервера';
$lang['Congratulations, Piwigo installation is completed'] = 'Вітаємо, Piwigo завершив встановлення';
$lang['Connection to server succeed, but it was impossible to connect to database'] = 'З\'єднання з сервером успішно, але з\'єднання з базою даних неможлива';
$lang['Creation of config file local/config/database.inc.php failed.'] = 'Створення файлу конфігурації local/config/database.inc.php не вдалося.';
$lang['Database configuration'] = 'Конфігурація бази даних';
$lang['Database name'] = 'Ім\'я бази даних';
$lang['Database table prefix'] = 'Префікс таблиць бази даних';
$lang['database tables names will be prefixed with it (enables you to manage better your tables)'] = 'таблиці бази даних імена, яких будуть починатися з префіксами (дозволяє управляти таблицями краще)';
$lang['Default gallery language'] = 'Типова мова галереї';
$lang['Download the config file'] = 'Завантажити файл конфігурації';
$lang['enter a login for webmaster'] = 'введіть лоґін веб-майстра';
$lang['Hope to see you back soon.'] = 'Сподіваюся побачити вас найближчим часом.';
$lang['Host'] = 'Хост';
$lang['Installation'] = 'Встановлення';
$lang['It appears your webhost is currently running PHP %s.'] = 'Схоже, ваш хостинг в даний час працює з PHP %s.';
$lang['It will be shown to the visitors. It is necessary for website administration'] = 'Він буде показаний відвідувачам. Це необхідно для адміністрації сайту';
$lang['Just another Piwigo gallery'] = 'Ще одна галерея Piwigo';
$lang['Keep it confidential, it enables you to access administration panel'] = 'Тримайте його конфіденційність, він дозволяє отримати доступ до адміністративної панелі';
$lang['localhost, sql.multimania.com, toto.freesurf.fr'] = 'localhost, sql.hosting.com.ua, toto.1gb.ua';
$lang['mail address must be like xxx@yyy.eee (example : jack@altern.org)'] = 'пошта повинна бути xxx@yyy.eee (наприклад: animan@pixobox.org)';
$lang['Need help ? Ask your question on <a href="%s">Piwigo message board</a>.'] = 'Потрібна допомога? Задайте питання на <a href="%s">Дошці оголошень Piwigo </a>.';
$lang['Note you can change your configuration by yourself and restart Piwigo after that.'] = 'Зверніть увагу, ви можете змінити свою конфігурацію і перезавантажити собі Piwigo після цього.';
$lang['Password'] = 'Пароль';
$lang['Password [confirm]'] = 'Пароль [підтвердження]';
$lang['PHP 5 is required'] = 'Потрібен PHP 5';
$lang['Piwigo may try to switch your configuration to PHP 5 by creating or modifying a .htaccess file.'] = 'Piwigo можуть спробувати перемкнути конфігурацію PHP 5 шляхом створення або зміни .htaccess файлу.';
$lang['Piwigo was not able to configure PHP 5.'] = 'Piwigo не зміг налаштувати PHP 5.';
$lang['please enter your password again'] = 'введіть пароль ще раз';
$lang['Sorry!'] = 'Вибачте!';
$lang['Start Install'] = 'Початок встановлення';
$lang['Try to configure PHP 5'] = 'Спробуйте налаштувати PHP 5';
$lang['user login given by your host provider'] = 'лоґін користувача дізнайтесь у вашого хостинг-провайдера';
$lang['user password given by your host provider'] = 'лоґін користувача дізнайтесь у Вашого хостинг-провайдера';
$lang['verification'] = 'перевірка';
$lang['Visitors will be able to contact site administrator with this mail'] = 'Відвідувачі зможуть використовувати цю пошту, щоб зв\'язатися з адміністратором сайту';
$lang['Webmaster login'] = 'Лоґін веб-майстра';
$lang['webmaster login can\'t contain characters \' or "'] = 'лоґін веб-майстера не може містити символів \' або "';
$lang['Webmaster mail address'] = 'Адреса електронної пошти веб-майстра';
$lang['Webmaster password'] = 'Пароль веб-майстра';
$lang['Welcome to my photo gallery'] = 'Ласкаво просимо в фотогалерею';
$lang['You can download the config file and upload it to local/config directory of your installation.'] = 'Ви можете завантажити конфігураційний файл і завантажити його до local/config каталогу встановлення.';
$lang['You may referer to your hosting provider\'s support and see how you could switch to PHP 5 by yourself.'] = 'Ви повинні звернутися в службу підтримки вашого хостинг-провайдера і подивитися, як ви можете переключитися на PHP 5 самостійно.';
?>

==> piwigo-2.5.1.zip: piwigo/language/uk_UA/install.lang.php <==
<?php
// +-----------------------------------------------------------------------+
// | Piwigo - a PHP based photo gallery                                    |
// +-----------------------------------------------------------------------+
// | Copyright(C) 2008-2013 Piwigo Team                  http://piwigo.org |
// | Copyright(C) 2003-2008 PhpWebGallery Team    http://phpwebgallery.net |
// | Copyright(C) 2002-2003 Pierrick LE GALL   http://le-gall.net/pierrick |
// +-----------------------------------------------------------------------+
// | This program is free software; you can redistribute it and/or modify  |
// | it under the terms of the GNU General Public License as published by  |
// | the Free Software Foundation                                          |
// |                                                                       |
// | This program is distributed in the hope that it will be useful, but   |
// | WITHOUT ANY WARRANTY; without even the implied warranty of            |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU      |
// | General Public License for more details.                              |
// |                                                                       |
// | You should have received a copy of the GNU General Public License     |
// | along with this program; if not, write to the Free Software           |
// | Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, |
// | USA.                                                                  |
// +-----------------------------------------------------------------------+
$lang['Admin configuration'] = 'Конфігурація адміністратора';
$lang['also given by your host provider'] = 'також дізнайтесь у Вашого хостинг-провайдера';
$lang['An alternate solution is to copy the text in the box above and paste it into the file "local/config/database.inc.php" (Warning : database.inc.php must only contain what is in the textarea, no line return or space character)'] = 'Альтернативним рішенням є копіювання тексту в поле вище і вставте його в файл "local/config/database.inc.php" (Попередження: database.inc.php повинен містити тільки те, що в текстовому полі, без зворотної лінії або пропусків)';
$lang['Basic configuration'] = 'Базова конфігурація';
$lang['Can\'t connect to server'] = 'Не вдається підключитися до сервера';
$lang['Congratulations, Piwigo installation is completed'] = 'Вітаємо, Piwigo завершив встановлення';
$lang['Connection to server succeed, but it was impossible to connect to database'] = 'З\'єднання з сервером успішно, але з\'єднання з базою даних неможлива';
$lang['Creation of config file local/config/database.inc.php failed.'] = 'Створення файлу конфігурації local/config/database.inc.php не вдалося.';
$lang['Database configuration'] = 'Конфігурація бази даних';
$lang['Database name'] = 'Ім\'я бази даних';
$lang['Database table prefix'] = 'Префікс таблиць бази даних';
$lang['database tables names will be prefixed with it (enables you to manage better your tables)'] = 'таблиці бази даних імена, яких будуть починатися з префіксами (дозволяє управляти таблицями краще)';
$lang['Default gallery language'] = 'Типова мова галереї';
$lang['Don\'t hesitate to consult our forums for any help : %s'] = 'Не соромтеся проконсультуватися на форумі першим з будь-яким питанням: %s';
$lang['Download the config file'] = 'Завантажити файл конфігурації';
$lang['enter a login for webmaster'] = 'введіть лоґін веб-майстра';
$lang['Hope to see you back soon.'] = 'Сподіваюся побачити вас найближчим часом.';
$lang['Host'] = 'Хост';
$lang['Installation'] = 'Встановлення';
$lang['It appears your webhost is currently running PHP %s.'] = 'Схоже, ваш хостинг в даний час працює з PHP %s.';
$lang['It will be shown to the visitors. It is necessary for website administration'] = 'Він буде показаний відвідувачам. Це необхідно для адміністрації сайту';
$lang['Just another Piwigo gallery'] = 'Ще одна галерея Piwigo';
$lang['Keep it confidential, it enables you to access administration panel'] = 'Тримайте його конфіденційність, він дозволяє отримати доступ до адміністративної панелі';
$lang['localhost, sql.multimania.com, toto.freesurf.fr'] = 'localhost, sql.hosting.com.ua, toto.1gb.ua';
$lang['mail address must be like xxx@yyy.eee (example : jack@altern.org)'] = 'пошта повинна бути xxx@yyy.eee (наприклад: animan@pixobox.org)';
$lang['Need help ? Ask your question on <a href="%s">Piwigo message board</a>.'] = 'Потрібна допомога? Задайте питання на <a href="%s">форумі Piwigo</a>.';
$lang['Note you can change your configuration by yourself and restart Piwigo after that.'] = 'Зверніть увагу, ви можете змінити свою конфігурацію і перезавантажити собі Piwigo після цього.';
$lang['Password'] = 'Пароль';
$lang['Password [confirm]'] = 'Пароль [підтвердження]';
$lang['PHP 5 is required'] = 'Потрібен PHP 5';
$lang['Piwigo may try to switch your configuration to PHP 5 by creating or modifying a .htaccess file.'] = 'Piwigo можуть спробувати перемкнути конфігурацію PHP 5 шляхом створення або зміни .htaccess файлу.';
$lang['Piwigo was not able to configure PHP 5.'] = 'Piwigo не зміг налаштувати PHP 5.';
$lang['please enter your password again'] = 'введіть пароль ще раз';
$lang['Sorry!'] = 'Вибачте!';
$lang['Start Install'] = 'Початок встановлення';
$lang['Try to configure PHP 5'] = 'Спробуйте налаштувати PHP 5';
$lang['user login given by your host provider'] = 'лоґін користувача дізнайтесь у вашого хостинг-провайдера';
$lang['user password given by your host provider'] = 'лоґін користувача дізнайтесь у Вашого хостинг-провайдера';
$lang['verification'] = 'перевірка';
$lang['Visitors will be able to contact site administrator with this mail'] = 'Відвідувачі зможуть використовувати цю пошту, щоб зв\'язатися з адміністратором сайту';
$lang['Webmaster login'] = 'Лоґін веб-майстра';
$lang['webmaster login can\'t contain characters \' or "'] = 'лоґін веб-майстера не може містити символів \' або "';
$lang['Webmaster mail address'] = 'Адреса електронної пошти веб-майстра';
$lang['Webmaster password'] = 'Пароль веб-майстра';
$lang['Welcome to my photo gallery'] = 'Ласкаво просимо в фотогалерею';
$lang['Welcome to your new installation of Piwigo!'] = 'Ласкаво просимо у ваш новий встановлений Piwigo!';
$lang['You can download the config file and upload it to local/config directory of your installation.'] = 'Ви можете завантажити конфігураційний файл і завантажити його до local/config каталогу встановлення.';
$lang['You may referer to your hosting provider\'s support and see how you could switch to PHP 5 by yourself.'] = 'Ви повинні звернутися в службу підтримки вашого хостинг-провайдера і подивитися, як ви можете переключитися на PHP 5 самостійно.';
$lang['User'] = 'Користувач';
?>
